From c48346425ada1fa16a50b847d8c8b337f02f8fe5 Mon Sep 17 00:00:00 2001
From: Masahiko Sawada <sawada.mshk@gmail.com>
Date: Mon, 25 Nov 2024 21:32:09 -0800
Subject: [PATCH v3 2/2] Include necessary header files in radixtree.h.
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit

When #include'ing radixtree.h with RT_SHMEM, it could happen to raise
compiler errors due to missing some declarations of types and
functions.

This commit also removes the inclusion of postgres.h since it's
against our usual convention.

Backpatch to v17, where radixtree.h was introduced.

Reviewed-by: Heikki Linnakangas, Álvaro Herrera
Discussion: https://postgr.es/m/CAD21AoCU9YH%2Bb9Rr8YRw7UjmB%3D1zh8GKQkWNiuN9mVhMvkyrRg%40mail.gmail.com
Backpatch-through: 17
---
 src/include/lib/radixtree.h | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/src/include/lib/radixtree.h b/src/include/lib/radixtree.h
index 88bf695e3f3..1301f3fee44 100644
--- a/src/include/lib/radixtree.h
+++ b/src/include/lib/radixtree.h
@@ -151,13 +151,15 @@
  *-------------------------------------------------------------------------
  */
 
-#include "postgres.h"
-
 #include "nodes/bitmapset.h"
 #include "port/pg_bitutils.h"
 #include "port/simd.h"
 #include "utils/dsa.h"
 #include "utils/memutils.h"
+#ifdef RT_SHMEM
+#include "miscadmin.h"
+#include "storage/lwlock.h"
+#endif
 
 /* helpers */
 #define RT_MAKE_PREFIX(a) CppConcat(a,_)
-- 
2.43.5

